<?php
define('WC_BRAINTREE_GATEWAY', plugin_dir_path(__FILE__));
define('WC_BRAINTREE_SCRIPT_PATH', plugin_dir_url(__FILE__).'assets/');

function init_wc_braintree_payment_gateway(){
	class Braintree_For_Woocommerce extends WC_Payment_Gateway {
		
		public $environment;
		
		private $merchantId;
		
		private $private_key;
		
		private $public_key;
		
		public $form_type;
		
		public $payment_form_name;
		
		private $config;
		
		public $paypal_enabled;
		
		public $method_title;
		
		public function __construct(){
			$this->id = 'braintree_payment_gateway';
			
			$this->icon = '';
			$this->title = __('Credit Card', 'woocommerce');
			
			$this->has_fields = true;
			
			//$this->method_title = 'Braintree Payment Gateway';
			
		//	$this->method_description = 'Braintree Payment Gateway uses the Braintree PHP SDK to securely process online payments
					//using your Braintree merchant account information';
			
			$this->init_form_fields();
		
			$this->init_settings();
			
			$this->load_options();
			
			$this->run_configuration();
			
			$this->load_braintree_scripts();
			
			add_action( 'woocommerce_update_options_payment_gateways_' . $this->id, array( $this, 'process_admin_options' ) );
		
			wp_enqueue_script('wc-checkout', WC_BRAINTREE_SCRIPT_PATH.'js/checkout.js', array('jquery'), '', true);

			
		}
		
		private function load_options(){
			

			if (isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && $_SERVER['HTTP_X_FORWARDED_PROTO'] == 'https')
				$_SERVER['HTTPS'] = 'on';
			
			$license_status = get_braintree_payments_config('braintree_payments_license_status');
			$this->config['api_keys'] = maybe_unserialize(get_braintree_payments_config('braintree_api_keys_config'));
			$this->config['merchant_accounts'] = maybe_unserialize(get_braintree_payments_config('braintree_merchant_account_id_config'));
			$this->config['woopayments'] = maybe_unserialize(get_braintree_payments_config('braintree_payments_woocommerce_config'));
			$production = ($this->config['api_keys']['environment'] == 'production') ? true : false;
			
			if($license_status == 'inactive'){
				check_braintree_donations_license();
				$license_status = get_braintree_payments_config('braintree_payments_license_status');
				$production = ($license_status == 'inactive') ? false : true;
			}
			
		 	 if($production && !is_ssl()){
				$production = false;
			}  
			
			$this->environment = ($production) ? 'production' : 'sandbox';
			$this->merchantId = ($production) ? $this->config['api_keys']['production']['merchantId'] : $this->config['api_keys']['sandbox']['merchantId'];
			$this->public_key = ($production) ? $this->config['api_keys']['production']['public_key'] : $this->config['api_keys']['sandbox']['public_key'];
			$this->private_key  = ($production) ? $this->config['api_keys']['production']['private_key'] : $this->config['api_keys']['sandbox']['private_key'];
			$this->merchantAccountId = ($production)
				? $this->config['merchant_accounts']['production']['merchant_account_id'] : $this->config['merchant_accounts']['sandbox']['merchant_account_id'];
			$this->paypal_enabled = ($this->config['woopayments']['woopayments_paypal_enabled'] == 'true') ? true : false;
			

			$this->form_type = $this->config['woopayments']['payment_form_type'];
			$this->payment_form_name = $this->config['woopayments']['payment_form'];
			
		}
		
		private function run_configuration(){
			if(class_exists('Braintree_Configuration')){
				Braintree_Configuration::environment($this->environment);
				Braintree_Configuration::merchantId($this->merchantId);
				Braintree_Configuration::publicKey($this->public_key);
				Braintree_Configuration::privateKey($this->private_key);
			}
		}
		
		public function get_client_token($user_customer = true){
			if($user_customer && $user = wp_get_current_user()){
				return Braintree_ClientToken::generate(array('customerId'=>$user->ID));
			}
			try{
				return Braintree_ClientToken::generate();
			}
			catch(Exception $e){
				return false;
			}
		}
		
		public function process_payment($order_id){
			return apply_filters('process_customer_payment', $order_id, $this);
		}
		
		public function get_paypal_container(){
			return '<div class="paypal-container">
					<div class="paypal-pay"><span>Pay With Paypal</span></div>
					<div id="paypal-container"></div>
				</div>
				<input type="hidden" id="paypal_active"/>
					<input type="hidden" id="payment_method_nonce" name="payment_method_nonce"/>
			<script type="text/javascript">
				var $ = jQuery;
					$(document).ready(function(){
				var client_token = $("#client_token").val();
				braintree.setup(client_token, "paypal", {container: "paypal-container",
						onPaymentMethodReceived: function(obj){
							if(obj){
						$("#payment_method_nonce").val(obj.nonce);
						$("#payment_type").val(obj.type);
					}
					}});
					});
			</script>';
		}
		
	public function get_current_braintree_user($user_id){
	try{
	$user = Braintree_Customer::find($user_id);
		return $user;
	}
	catch(Exception $e){
		return false;
	}
}

public function get_user_cards($braintree_user){
	if($braintree_user){
	if($braintree_user->paymentMethods){
	$html =	'<div class="payment-info-container"><div class="use-saved-card"><div><span>Use Saved</span></div><input type="checkbox" name="use_saved_card" value="true"/></div><div class="saved-payment-methods"><select name="existing_card">';
			foreach($braintree_user->creditCards as $card => $creditCard) {
				$html .= '<option name="saved_card" value="'.$creditCard->token.'">'.$creditCard->cardType.' - '.$creditCard->maskedNumber.'</option>';
			}
		$html .= '</select></div></div>';
	return $html;
	}
}
}
		/**
		 * Verify that force SSL option is set to true. If it is not, then do not allow the 
		 * customer to use the payment gateway using production keys. First, the code checks to see if woocommerce
		 * force SSL in checkout is set. If not, the header for 'HTTPS' is checked. If that is also false, then the wordpress
		 * function is_ssl() is called. If the function returns false, then Braintree is loaded using the sandbox public and private
		 * keys
		 */
		private function is_ssl_enabled(){
			$ssl_option = 'yes' == get_option('woocommerce_force_ssl_checkout', true) ? true : false;
			if(!$ssl_option){
					if(!is_ssl()){
					return false;
				}
			}
			return true;
		}
		public function payment_fields(){
			apply_filters('get_braintree_checkout_ui', $this);
       }
       public function load_braintree_scripts(){
       	wp_enqueue_script('braintree-custom-ui-script', WC_BRAINTREE_SCRIPT_PATH.'js/braintree.js', array('jquery'), '', true );
  		wp_enqueue_style('payment-form-style', WC_BRAINTREE_SCRIPT_PATH.'css/'.$this->payment_form_name.'.css');
       }
  
  public function get_active_environment(){
  	if($this->environment == 'sandbox'){
  		return '<div class="active-environment-message"><span>Sandbox Active</span></div>';
  	}
  }
}
}
add_action('plugins_loaded', 'init_wc_braintree_payment_gateway');


function add_braintree_payment_gateway($methods){
	$methods[] = 'Braintree_For_Woocommerce';
	return $methods;
	
}
add_filter('woocommerce_payment_gateways', 'add_braintree_payment_gateway');

function load_dependencies(){
	include_once(WC_BRAINTREE_GATEWAY.'includes/payment-functions.php');
	include_once(WC_BRAINTREE_GATEWAY.'includes/payment-forms.php');
}

load_dependencies();

function remove_wc_checkout(){
	wp_dequeue_script('wc-checkout');
		
}
add_action('after_setup_theme', 'remove_wc_checkout');

/* function load_scripts(){
	$settings = get_option('woocommerce_braintree_payment_gateway_settings', true);
	$form_type = $settings['braintree_dropin_ui'];
	if($form_type == 'yes'){
		$located = apply_filters('get_braintree_template_scripts', WC_BRAINTREE_SCRIPT_PATH, 'checkout-script-dropin', 'js/checkout-dropin.js');
		wp_enqueue_script('wc-checkout', $located.'js/checkout-dropin.js', array('braintree-custom-ui-script'), '', true);
	}
	
	else {
		$located = apply_filters('get_braintree_template_scripts', WC_BRAINTREE_SCRIPT_PATH, 'checkout-script-custom', 'js/checkout-custom.js');
		wp_enqueue_script('wc-checkout', $located.'js/checkout-custom.js', array('braintree-custom-ui-script'), '', true);
	}

} */

/* function load_braintree_style_files(){
	$located = apply_filters('get_braintree_template_scripts', WC_BRAINTREE_SCRIPT_PATH, 'checkout-styles', 'css/braintree-for-woocommerce.css');
	wp_enqueue_style('checkout-script-dropin', $located.'css/braintree-for-woocommerce.css');
}
add_action('woocommerce_before_checkout_form', 'load_braintree_style_files'); */

function load_admin_scripts(){
	wp_enqueue_script('braintree-admin-script', plugin_dir_url(__FILE__).'admin/js/braintree-admin.js');
}
add_action('admin_init', 'load_admin_scripts');
?>